@@ -1,7 +1,3 @@
-/*
- $Id: lfe.h 2020 2016-04-27 05:13:51Z sgaure $
-*/
-
 #include "config.h"
 
 /* different syntax in pthread_setname_np between platforms, disable for now */
@@ -17,7 +13,7 @@
 
 #ifndef NOTHREADS
 #ifdef HAVE_THREADNAME
-#define _GNU_SOURCE             /* to find pthread_setname_np */
+#define _GNU_SOURCE /* to find pthread_setname_np */
 #endif
 
 #include <semaphore.h>
@@ -33,7 +29,7 @@ int pthread_setname_np(pthread_t thread, const char *name);
 #define STNAME(s) pthread_setname_np(pthread_self(), s)
 #elif __APPLE__
 // Mac OS X: must be set from within the thread (can't specify thread ID)
-int pthread_setname_np(const char*);
+int pthread_setname_np(const char *);
 #define STNAME(s) pthread_setname_np(s)
 #elif __FreeBSD__
 // FreeBSD & OpenBSD: function name is slightly different, and has no return value
@@ -65,7 +61,6 @@ void pthread_set_name_np(pthread_t tid, const char *name);
 #include <R_ext/Visibility.h>
 #include <R_ext/BLAS.h>
 
-
 #if defined(R_VERSION) && R_VERSION >= R_Version(3, 0, 0)
 typedef R_xlen_t mybigint_t;
 #else
@@ -76,7 +71,7 @@ typedef int mybigint_t;
    This will increase the memory usage, so we wait until it's needed.
 */
 
-#ifdef HUGE_INT 
+#ifdef HUGE_INT
 typedef R_xlen_t mysize_t;
 #else
 typedef int mysize_t;
@@ -84,42 +79,41 @@ typedef int mysize_t;
 
 /* Locking macros */
 #ifdef NOTHREADS
-#define LOCK_T int*
+#define LOCK_T int *
 #define LOCK(l)
 #define UNLOCK(l)
 #else
 
 #ifdef WIN
 #define LOCK_T HANDLE
-#define LOCK(l) WaitForSingleObject(l,INFINITE)
+#define LOCK(l) WaitForSingleObject(l, INFINITE)
 #define UNLOCK(l) ReleaseMutex(l)
 #else
-#define LOCK_T pthread_mutex_t*
+#define LOCK_T pthread_mutex_t *
 #define LOCK(l) (void)pthread_mutex_lock(l)
 #define UNLOCK(l) (void)pthread_mutex_unlock(l)
 #endif
 #endif
 
 /* My internal definition of a factor */
-typedef struct {
+typedef struct
+{
   /* group[i] is the level of observation i */
   int *group;
   /* invgpsize[j] is the 1/(size of level j) */
-  double *invgpsize;  
+  double *invgpsize;
   double *gpsize;
-  int *gpl; /* group list */
-  int *ii;  /* indices into gpl */
+  int *gpl;  /* group list */
+  int *ii;   /* indices into gpl */
   double *x; /* optional interaction covariate */
   int nlevels;
   int oneiter;
 } FACTOR;
 
-
-
 /* Routines used in more than one source file */
-FACTOR** makefactors(SEXP flist, int allowmissing, double *weights);
-int checkInterrupt();
-void initmsg();
+FACTOR **makefactors(SEXP flist, int allowmissing, double *weights);
+extern int checkInterrupt(void);
+extern void initmsg(void);
 void pushmsg(char *s, LOCK_T lock);
 void printmsg(LOCK_T lock);
 
@@ -128,8 +122,8 @@ SEXP MY_kaczmarz(SEXP flist, SEXP vlist, SEXP Reps, SEXP initial, SEXP Rcores);
 SEXP MY_wwcomp(SEXP flist);
 SEXP MY_conncomp(SEXP flist);
 SEXP MY_demeanlist(SEXP vlist, SEXP flist, SEXP Ricpt, SEXP Reps,
-		   SEXP scores, SEXP quiet, SEXP gkacc, SEXP Rmeans,
-		   SEXP weights, SEXP Rscale, SEXP attrs);
+                   SEXP scores, SEXP quiet, SEXP gkacc, SEXP Rmeans,
+                   SEXP weights, SEXP Rscale, SEXP attrs);
 SEXP MY_scalecols(SEXP mat, SEXP vec);
 SEXP MY_pdaxpy(SEXP inX, SEXP inY, SEXP inbeta);
 SEXP MY_piproduct(SEXP inX, SEXP inY);
@@ -137,9 +131,8 @@ SEXP MY_setdimnames(SEXP obj, SEXP nm);
 SEXP MY_dsyrk(SEXP inbeta, SEXP inC, SEXP inalpha, SEXP inA);
 SEXP MY_sandwich(SEXP inalpha, SEXP inbread, SEXP inmeat);
 SEXP MY_address(SEXP x);
-//SEXP MY_named(SEXP x, SEXP n);
+// SEXP MY_named(SEXP x, SEXP n);
 SEXP inplace(SEXP x);
-SEXP Crowsum(SEXP Rmat, SEXP Rfactor, SEXP Rmean);
+SEXP crowsum(SEXP Rmat, SEXP Rfactor, SEXP Rmean);
 
 // SEXP MY_ppf(SEXP flist, SEXP Rtype);
-
